Class: Mongoid::Relations::Metadata
- Inherits:
-
Hash
- Object
- Hash
- Mongoid::Relations::Metadata
- Defined in:
- lib/mongoid-multiple-polymorphic/mongoid/relations/metadata.rb
Instance Method Summary collapse
-
#inverse_of_field ⇒ String
Returns the name of the field in which to store the name of the inverse field for the polymorphic relation.
-
#inverse_of_field_setter ⇒ String
Gets the setter for the field that stores the name of the inverse field on a polymorphic relation.
Instance Method Details
#inverse_of_field ⇒ String
Returns the name of the field in which to store the name of the inverse field for the polymorphic relation.
14 15 16 |
# File 'lib/mongoid-multiple-polymorphic/mongoid/relations/metadata.rb', line 14 def inverse_of_field @inverse_of_field ||= determine_inverse_for(:field) end |
#inverse_of_field_setter ⇒ String
Gets the setter for the field that stores the name of the inverse field on a polymorphic relation.
25 26 27 |
# File 'lib/mongoid-multiple-polymorphic/mongoid/relations/metadata.rb', line 25 def inverse_of_field_setter @inverse_of_field_setter ||= inverse_of_field.__setter__ end |